Description: Lists all of the available service-specific resources, actions, and condition keys that can be used in IAM policies to control access to Amazon Interactive Video Service.
Keywords: IAM,AWS Identity and Access Management,IAM user,user,IAM group,group,IAM role,role,permission policy,trust policy,policy,access key,password

Actions, resources, and condition keys for Amazon Interactive Video Service - AWS Identity and Access Management

# Actions, resources, and condition keys for Amazon Interactive Video Service

Tip

This page is moving to a new location on November 16, 2020. Please update your bookmark to use the new page at https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazoninteractivevideoservice.html .

Amazon Interactive Video Service (service prefix: `ivs` ) provides the following service-specific resources, actions, and condition context keys for use in IAM permission policies.

References:

- Learn how to configure this service .

- View a list of the API operations available for this service .

- Learn how to secure this service and its resources by using IAM permission policies.

Topics

- Actions defined by Amazon Interactive Video Service
- Resource types defined by Amazon Interactive Video Service
- Condition keys for Amazon Interactive Video Service

## Actions defined by Amazon Interactive Video Service

You can specify the following actions in the `Action` element of an IAM policy statement. Use policies to grant permissions to perform an operation in AWS. When you use an action in a policy, you usually allow or deny access to the API operation or CLI command with the same name. However, in some cases, a single action controls access to more than one operation. Alternatively, some operations require several different actions.

The Resource types column indicates whether each action supports resource-level permissions. If there is no value for this column, you must specify all resources ("*") in the `Resource` element of your policy statement. If the column includes a resource type, then you can specify an ARN of that type in a statement with that action. Required resources are indicated in the table with an asterisk (*). If you specify a resource-level permission ARN in a statement using this action, then it must be of this type. Some actions support multiple resource types. If the resource type is optional (not indicated as required), then you can choose to use one but not the other.

For details about the columns in the following table, see The actions table .

Actions | Description | Access level | Resource types (*required) | Condition keys | Dependent actions
--- | --- | --- | --- | --- | ---
BatchGetChannel | Grants permission to get multiple channels simultaneously by channel ARN. | Read | Channel* |  |
BatchGetStreamKey | Grants permission to get multiple stream keys simultaneously by stream key ARN. | Read | Stream-Key* |  |
CreateChannel | Grants permission to create a new channel and an associated stream key. | Write | Channel* |  |
Stream-Key* |  |
| aws:TagKeys aws:RequestTag/${TagKey} |
CreateStreamKey | Grants permission to create a stream key. | Write | Stream-Key* |  |
| aws:TagKeys aws:RequestTag/${TagKey} |
DeleteChannel | Grants permission to delete a channel and channel's stream keys. | Write | Channel* |  |
Stream-Key* |  |
DeletePlaybackKeyPair | Grants permission to delete the playback key pair for a specified ARN | Write | Playback-Key-Pair* |  |
DeleteStreamKey | Grants permission to delete the stream key for a specified ARN | Write | Stream-Key* |  |
GetChannel | Grants permission to get the channel configuration for a specified channel ARN | Read | Channel* |  |
GetPlaybackKeyPair | Grants permission to get the playback keypair information for a specified ARN | Read | Playback-Key-Pair* |  |
GetStream | Grants permission to get information about the active (live) stream on a specified channel | Read | Channel* |  |
GetStreamKey | Grants permission to get stream-key information for a specified ARN | Read | Stream-Key* |  |
ImportPlaybackKeyPair | Grants permission to import the public key. | Write | Playback-Key-Pair* |  |
| aws:TagKeys aws:RequestTag/${TagKey} |
ListChannels | Grants permission to get summary information about channels | List | Channel* |  |
ListPlaybackKeyPairs | Grants permission to get summary information about playback key pairs | List | Playback-Key-Pair* |  |
ListStreamKeys | Grants permission to get summary information about stream keys | List | Channel* |  |
Stream-Key* |  |
ListStreams | Grants permission to get summary information about live streams | List | Channel* |  |
ListTagsForResource | Grants permission to get information about the tags for a specified ARN | Tagging | Channel |  |
Playback-Key-Pair |  |
Stream-Key |  |
| aws:TagKeys aws:RequestTag/${TagKey} |
PutMetadata | Grants permission to insert metadata into an RTMP stream for a specified channel | Write | Channel* |  |
StopStream | Grants permission to disconnect a streamer on a specified channel | Write | Channel* |  |
TagResource | Grants permission to add or update tags for a resource with a specified ARN | Tagging | Channel |  |
Playback-Key-Pair |  |
Stream-Key |  |
| aws:TagKeys aws:RequestTag/${TagKey} |
UntagResource | Grants permission to remove tags for a resource with a specified ARN | Tagging | Channel |  |
Playback-Key-Pair |  |
Stream-Key |  |
| aws:TagKeys |
UpdateChannel | Grants permission to update a channel's configuration | Write | Channel* |  |

## Resource types defined by Amazon Interactive Video Service

The following resource types are defined by this service and can be used in the `Resource` element of IAM permission policy statements. Each action in the Actions table identifies the resource types that can be specified with that action. A resource type can also define which condition keys you can include in a policy. These keys are displayed in the last column of the table. For details about the columns in the following table, see The resource types table .

Resource types | ARN | Condition keys
--- | --- | ---
Channel | `arn:$ { Partition}:ivs::$ { Account}:channel/$ { ResourceId}` | aws:ResourceTag/${TagKey}
Stream-Key | `arn:$ { Partition}:ivs::$ { Account}:stream-key/$ { ResourceId}` | aws:ResourceTag/${TagKey}
Playback-Key-Pair | `arn:$ { Partition}:ivs::$ { Account}:playback-key/$ { ResourceId}` | aws:ResourceTag/${TagKey}

## Condition keys for Amazon Interactive Video Service

Amazon Interactive Video Service defines the following condition keys that can be used in the `Condition` element of an IAM policy. You can use these keys to further refine the conditions under which the policy statement applies. For details about the columns in the following table, see The condition keys table .

To view the global condition keys that are available to all services, see Available global condition keys .

Condition keys | Description | Type
--- | --- | ---
aws:RequestTag/${TagKey} | Filters actions based on the tags associated with the request | String
aws:ResourceTag/${TagKey} | Filters actions based on the tags associated with the resource | String
aws:TagKeys | Filters actions based on the tag keys that are passed in the request | String

Did this page help you? - Yes

Thanks for letting us know we're doing a good job!

If you've got a moment, please tell us what we did right so we can do more of it.

Did this page help you? - No

Thanks for letting us know this page needs work. We're sorry we let you down.

If you've got a moment, please tell us how we can make the documentation better.